# -*- coding: utf-8 -*-
# (c) Dirk Gütlin, 2021. <dirk.guetlin@gmail.com>
#
# License: BSD-3-Clause

"""
Welcome to the ASRpy documentation.

You find the documentation to all available functions by clicking on
the respective submodules.

"""

from .asr import ASR, asr_calibrate, asr_process, clean_windows
